// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "scene/Scene.hpp"
#include "prefabs/SimpleSpinningCubePrefab.hpp"
#include "prefabs/TicTacToeTilePrefab.hpp"

namespace Dawn {
  class TicTacToeScene : public Scene {
    protected:
      Camera *camera;
      TicTacToeTilePrefab* tiles[9];

      void stage() override {
        camera = Camera::create(this);
        camera->transform->lookAt(glm::vec3(5, 5, 5), glm::vec3(0, 0, 0));

        int32_t i = 0;
        for(int32_t x = -1; x <= 1; x++) {
          for(int32_t y = -1; y <= 1; y++) {
            auto tile = TicTacToeTilePrefab::prefabCreate(this);
            tile->transform.setLocalPosition(glm::vec3(x * 1.25f, y * 1.25f, 0));
            // tile->ticTacToe->setState(i % 2 == 0 ? TIC_TAC_TOE_CROSS : TIC_TAC_TOE_NOUGHT);
            tiles[i++] = tile;
          }
        }

        
      }
      
      std::vector<Asset*> getRequiredAssets() override {
        auto assMan = &this->game->assetManager;
        std::vector<Asset*> assets;
        vectorAppend(&assets, SimpleSpinningCubePrefab::getRequiredAssets(assMan));
        vectorAppend(&assets, TicTacToeTilePrefab::getRequiredAssets(assMan));
        return assets;
      }

    public:
      TicTacToeScene(DawnGame *game) : Scene(game) {}
  };
}